import $ from "jquery"
import Timer from "easytimer.js"

const assignEventListeners = (timer) => {
    timer.addEventListener(
        'secondsUpdated',
        (event) => {
            $('#timer .timer-values').html(timer.getTimeValues().toString())
        }
    )

    timer.addEventListener(
        'targetAchieved',
        (event) => {
            $("#is_counting").prop("checked", false)
            $('#timer .timer-values').html("Konec")
        }
    )

    $('#timer .timer-values').html(timer.getTimeValues().toString())
}

$(window).ready(
    () => {
        // --- BEGIN Timer ---

        let timer = new Timer({
            countdown: true,
            startValues: {
                hours: window.startingTime.hours,
                minutes: window.startingTime.minutes,
                seconds: window.startingTime.seconds,
            }
        })

        const timerSocket = new WebSocket(
            "wss://"
            + window.location.host
            + "/ws/timer/"
        )

        timerSocket.onmessage = (event) => {
            const data = JSON.parse(event.data)

            if ("status" in data) {
                if (data["status"] === "playing") {
                    // Reset if we are playing again.
                    if (!timer.isRunning()) {
                        timer = new Timer({
                            countdown: true,
                            startValues: {
                                hours: window.startingTime.hours,
                                minutes: window.startingTime.minutes,
                                seconds: window.startingTime.seconds,
                            }
                        })

                        assignEventListeners(timer)
                    }

                    timer.start()
                } else if (data["status"] === "paused") {
                    timer.pause()
                }
            } else if ("time" in data) {
                timer.pause()

                window.startingTime = {
                    hours: data["time"]["hours"],
                    minutes: data["time"]["minutes"],
                    seconds: data["time"]["seconds"]
                }

                timer = new Timer({
                    countdown: true,
                    startValues: {
                        hours: window.startingTime.hours,
                        minutes: window.startingTime.minutes,
                        seconds: window.startingTime.seconds,
                    }
                })

                assignEventListeners(timer)
            }
        }

        assignEventListeners(timer)

        // --- END Timer ---

        // --- BEGIN Controls ---

        $("#is_counting").on(
            "change",
            (event) => {
                if (event.target.checked) {
                    timerSocket.send(JSON.stringify({
                        "status": "playing"
                    }))
                } else {
                    timerSocket.send(JSON.stringify({
                        "status": "paused"
                    }))
                }
            }
        )

        $("#update-time").on(
            "click",
            (event) => {
                timerSocket.send(JSON.stringify({
                    "time": {
                        "hours": Number($("#hours").val()),
                        "minutes": Number($("#minutes").val()),
                        "seconds": Number($("#seconds").val())
                    }
                }))

                $("#is_counting").prop("checked", false)
            }
        )

        // --- END Controls ---
    }
)
