import json

from asgiref.sync import async_to_sync
from channels.generic.websocket import WebsocketConsumer


class TimerConsumer(WebsocketConsumer):
    def connect(self):
        async_to_sync(self.channel_layer.group_add)("timer", self.channel_name)

        self.accept()

    def disconnect(self, close_code):
        pass

    def receive(self, text_data):
        json_data = json.loads(text_data)

        response = None

        if "status" in json_data:
            if json_data["status"] == "playing":
                response = {"status": "playing"}
            elif json_data["status"] == "paused":
                response = {"status": "paused"}

        if "time" in json_data:
            response = {
                "time": {
                    "hours": json_data["time"]["hours"],
                    "minutes": json_data["time"]["minutes"],
                    "seconds": json_data["time"]["seconds"],
                }
            }

        if response is not None:
            async_to_sync(self.channel_layer.group_send)(
                "timer", {"type": "timer_message", "text": json.dumps(response)}
            )

        self.send(text_data=json.dumps({}))

    def timer_message(self, event):
        self.send(text_data=event["text"])
